BrickRegistry class abstract final

Static registry of all available FlAI component bricks.

Properties

hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited

Static Properties

categories List<String>
Returns all unique categories in display order.
no setter

Static Methods

byCategory(String category) List<BrickInfo>
Returns all bricks belonging to category.
lookup(String name) BrickInfo?
Looks up a brick by name. Returns null if not found.

Constants

components → const Map<String, BrickInfo>