FlaiConfig class

Represents the contents of a project's flai.yaml.

Constructors

FlaiConfig({String outputDir = 'lib/flai', String theme = 'dark', List<String> installed = const []})
const
FlaiConfig.fromYaml(Map yaml)
Creates a FlaiConfig from a parsed YAML map.
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
installed List<String>
Names of components already installed in this project.
final
outputDir String
Directory (relative to project root) where generated components are placed.
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
theme String
Active theme name.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
toYamlString() String
Serialises this config to a YAML string.

Operators

operator ==(Object other) bool
The equality operator.
inherited