FlaiConfigManager class

Utilities for reading and writing the flai.yaml configuration file.

Constructors

FlaiConfigManager({required String projectRoot})

Properties

configPath → String
Absolute path to the config file.
no setter
exists → bool
Whether the config file exists.
no setter
hashCode → int
The hash code for this object.
no setterinherited
projectRoot → String
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

createDefault() → FlaiConfig
Creates the initial config file with default values.
markInstalled(List<String> componentNames) → void
Adds componentNames to the installed list and persists the change.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
read() → FlaiConfig
Reads and parses the config file.
toString() → String
A string representation of this object.
inherited
write(FlaiConfig config) → void
Writes a FlaiConfig to disk.

Operators

operator ==(Object other) → bool
The equality operator.
inherited