BrickInfo class
Metadata for a single FlAI component brick.
Constructors
Properties
- category → String
-
final
-
dependencies
→ List<
String> -
Other FlAI components this brick depends on.
final
- description → String
-
final
- hashCode → int
-
The hash code for this object.
no setterinherited
- name → String
-
final
-
pubDependencies
→ List<
String> -
Pub.dev packages that must be added to the project's pubspec.yaml.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited